@@ -60,7 +60,6 @@ struct translator {
 };
 
 static struct developer developers[] = {
-	{"Rob Flynn",					N_("maintainer"), "gaim@robflynn.com"},
 	{"Sean Egan",					N_("lead developer"), "sean.egan@binghamton.edu"},
 	{"Daniel 'datallah' Atallah",	N_("developer"),	NULL},
 	{"Christian 'ChipX86' Hammond",	N_("developer & webmaster"), NULL},
@@ -70,8 +69,9 @@ static struct developer developers[] = {
 	{"Ethan 'Paco-Paco' Blanton",	N_("developer"), NULL},
 	{"Etan 'deryni' Reisner",       N_("developer"), NULL},
 	{"Tim 'marv' Ringenbach",		N_("developer"), NULL},
-	{"Luke 'LSchiere' Schierer",	N_("support"), NULL},
+	{"Luke 'LSchiere' Schierer",	N_("support"), "lschiere@users.sf.net"},
 	{"Stu 'nosnilmot' Tomlinson",	N_("developer"), NULL},
+	{"Gary 'grim' Kramlich",		N_("developer"), NULL},
 	{NULL, NULL, NULL}
 };
 
@@ -79,7 +79,6 @@ static struct developer patch_writers[] = {
 	{"Ka-Hing 'javabsp' Cheung",	NULL,	NULL},
 	{"Felipe 'shx' Contreras",		NULL,	NULL},
 	{"Decklin Foster",				NULL,	NULL},
-	{"Gary 'grim' Kramlich",		NULL,	NULL},
 	{"Robert 'Robot101' McQueen",	NULL,	NULL},
 	{"Benjamin Miller",				NULL,	NULL},
 	{"Kevin 'SimGuy' Stange",		NULL,	NULL},
@@ -87,46 +86,50 @@ static struct developer patch_writers[] = {
 };
 
 static struct developer retired_developers[] = {
+	{"Rob Flynn",					N_("maintainer"), "gaim@robflynn.com"},
 	{"Adam Fritzler",		N_("former libfaim maintainer"), NULL},
 	{"Eric Warmenhoven",	N_("former lead developer"), "warmenhoven@yahoo.com"},
 	{"Jim Duchek",			N_("former maintainer"), NULL},
-	{"Jim Seymour",			N_("former Jabber developer"), NULL},
+    {"Jim Seymour",         N_("former Jabber developer"), NULL},
 	{"Mark Spencer",		N_("original author"), "markster@marko.net"},
 	{"Syd Logan",			N_("hacker and designated driver [lazy bum]"), NULL},
 	{NULL, NULL, NULL}
 };
 
 static struct translator current_translators[] = {
-	{N_("Albanian"),            "sq", "Programe Shqip", "besnik@spymac.com"},
-	{N_("Bulgarian"),			"bg", "Alexander Shopov", "al_shopov@users.sf.net"},
+	{"Azerbaijani",				"az", "Metin Amiroff", "metin@karegen.com"},
+    {N_("Bulgarian"),           "bg", N_("Vladimira Girginova and Vladimir (Kaladan) Petkov"), "missing@here.is,vpetkov@i-space.org"},
 	{N_("Catalan"),				"ca", "Josep Puigdemont", "tradgnome@softcatala.org"},
 	{N_("Czech"),				"cs", "Miloslav Trmac", "mitr@volny.cz"},
-	{N_("Danish"),				"da", "Morten Brix Pedersen", "morten@wtf.dk"},
-	{N_("Australian English"),	"en_AU", "Peter Lawler", "trans@six-by-nine.com.au"},
-	{N_("British English"),		"en_GB", "Luke Ross", "lukeross@sys3175.co.uk"},
-	{N_("Canadian English"),	"en_CA", "Adam Weinberger", "adamw@gnome.org"},
+    {N_("Danish"),              "da", "Morten Brix Pedersen", "morten@wtf.dk"},
 	{N_("German"),				"de", "Björn Voigt", "bjoern@cs.tu-berlin.de"},
+	{N_("Australian English"),	"en_AU", "Peter Lawler", "trans -at- six-by-nine.com.au"},
+	{N_("Canadian English"),	"en_CA", "Adam Weinberger", "adamw@gnome.org"},
+    {N_("British English"),     "en_GB", "Luke Ross", "lukeross@sys3175.co.uk"},
 	{N_("Spanish"),				"es", "Javier Fernández-Sanguino Peña", "jfs@debian.org"},
+	{N_("Estonian"),            "et", "Ivar Smolin", "okul@users.sf.net"},
 	{N_("Finnish"),				"fi", "Arto Alakulju", "arto@alakulju.net"},
 	{N_("French"),				"fr", "Éric Boumaour", "zongo_fr@users.sourceforge.net"},
 	{N_("Hebrew"),				"he", "Pavel Bibergal", "cyberkm203@hotmail.com"},
 	{N_("Hindi"),				"hi", "Ravishankar Shrivastava", "raviratlami@yahoo.com"},
-	{N_("Hungarian"),			"hu", "Zoltan Sutto", "suttozoltan@chello.hu"},
+	{N_("Hungarian"),			"hu", "Zoltan Sutto", "sutto.zoltan@rutinsoft.hu"},
 	{N_("Italian"),				"it", "Claudio Satriano", "satriano@na.infn.it"},
 	{N_("Japanese"),			"ja", "Takashi Aihana", "aihana@gnome.gr.jp"},
-	{N_("Lithuanian"),			"lt", "Gediminas Čičinskas", "gediminas@parok.lt"},
+	{N_("Georgian"),            "ka", "Temuri Doghonadze", "admin@security.gov.ge"},
 	{N_("Korean"),				"ko", "Kyung-uk Son", "vvs740@chol.com"},
-	{N_("Dutch; Flemish"),		"nl", "Vincent van Adrighem", "V.vanAdrighem@dirck.mine.nu"},
+	{N_("Lithuanian"),			"lt", "Gediminas Čičinskas", "gediminas@parok.lt"},
 	{N_("Macedonian"),			"mk", "Tomislav Markovski", "herrera@users.sf.net"},
 	{N_("Burmese"),             "my_MM", "Minn Myat Soe", "mmyatsoe@gmail.com"},
-	{N_("Norwegian"),			"no", "Petter Johan Olsen", "petter.olsen@cc.uit.no"},
+	{N_("Dutch; Flemish"),		"nl", "Vincent van Adrighem", "V.vanAdrighem@dirck.mine.nu"},
+	{N_("Norwegian"),			"no", "Kyrre Ness Sjøbæk", "kyrsjo@users.sf.net"},
 	{N_("Polish"),				"pl", "Krzysztof Foltman, Emil Nowak", "krzysztof@foltman.com;emil5@go2.pl"},
 	{N_("Portuguese"),			"pt", "Duarte Henriques", "duarte_henriques@myrealbox.com"},
 	{N_("Portuguese-Brazil"),	"pt_BR", "Maurício de Lemos Rodrigues Collares Neto", "mauricioc@gmail.com"},
 	{N_("Romanian"),			"ro", "Mişu Moldovan", "dumol@go.ro"},
 	{N_("Russian"),				"ru", "Dmitry Beloglazov", "dmaa@users.sf.net"},
-	{N_("Serbian"),				"sr", "Danilo Šegan, Aleksandar Urosevic", "dsegan@gmx.net;urke@users.sourceforge.net"},
 	{N_("Slovenian"),			"sl", "Martin Srebotnjak", "miles@filmsi.net"},
+	{N_("Albanian"),            "sq", "Programe Shqip", "besnik@spymac.com"},
+	{N_("Serbian"),				"sr", "Danilo Šegan, Aleksandar Urosevic", "dsegan@gmx.net;urke@users.sourceforge.net"},
 	{N_("Swedish"),				"sv", "Peter Hjalmarsson", "xake@telia.com"},
 	{N_("Turkish"),             "tr", "Onur Kucuktunc", "onurcc@gmail.com"},
 	{N_("Ukrainian"),           "uk", "Maxim V. Dziumanenko", "mvd@mylinux.com.ua"},
@@ -150,6 +153,7 @@ static struct translator past_translators[] = {
 	{N_("Italian"),				"it", "Salvatore di Maggio", NULL},
 	{N_("Japanese"),			"ja", "Ryosuke Kutsuna, Taku Yasui, Junichi Uekawa", NULL},
 	{N_("Korean"),				"ko", "Sang-hyun S, A Ho-seok Lee", NULL},
+	{N_("Norwegian"),			"no", "Petter Johan Olsen", "petter.olsen@cc.uit.no"},
 	{N_("Polish"),				"pl", "Przemysław Sułek", NULL},
 	{N_("Russian"),				"ru", "Sergey Volozhanin", NULL},
 	{N_("Russian"),				"ru", "Alexandre Prokoudine", NULL},
@@ -244,8 +248,13 @@ void gaim_gtkdialogs_about(GtkWidget *w, void *data)
 	g_string_append(str, "<FONT SIZE=\"4\">URL:</FONT> <A HREF=\""
 					GAIM_WEBSITE "\">" GAIM_WEBSITE "</A><BR/><BR/>");
 
+#ifdef _WIN32
+	g_string_append_printf(str, _("<FONT SIZE=\"4\">IRC:</FONT> "
+						   "#wingaim on irc.freenode.net<BR><BR>"));
+#else
 	g_string_append_printf(str, _("<FONT SIZE=\"4\">IRC:</FONT> "
 						   "#gaim on irc.freenode.net<BR><BR>"));
+#endif
 
 	/* Active Developers */
 	g_string_append_printf(str, "<FONT SIZE=\"4\">%s:</FONT><BR/>",
@@ -368,10 +377,15 @@ void gaim_gtkdialogs_about(GtkWidget *w, void *data)
 #else
 	g_string_append(str, "NSS:  Disabled<br/>");
 #endif
-#ifdef HAVE_TK
-	g_string_append(str, "TK:  Yes<br/>");
+#ifdef HAVE_TCL
+	g_string_append(str, "Tcl: Yes<br/>");
 #else
-	g_string_append(str, "TK:  No<br/>");
+	g_string_append(str, "Tcl: No<br/>");
+#endif
+#ifdef HAVE_TK
+	g_string_append(str, "Tk:  Yes<br/>");
+#else
+	g_string_append(str, "Tk:  No<br/>");
 #endif
 #ifdef LIBZEPHYR_EXT
 	g_string_append(str, "External libzephyr:  Yes<br/>");
@@ -990,11 +1004,14 @@ gaim_gtkdialogs_remove_chat_cb(GaimChat *chat)
 void
 gaim_gtkdialogs_remove_chat(GaimChat *chat)
 {
-	gchar *name = gaim_chat_get_display_name(chat);
-	gchar *text = g_strdup_printf(_("You are about to remove the chat %s from your buddy list.  Do you want to continue?"), name);
+	gchar *name, *text;
 
 	g_return_if_fail(chat != NULL);
 
+	name = gaim_chat_get_display_name(chat);
+	text = g_strdup_printf(_("You are about to remove the chat %s from your buddy list.  Do you want to continue?"),
+			name ? name : "");
+
 	gaim_request_action(chat, NULL, _("Remove Chat"), text, 0, chat, 2,
 						_("Remove Chat"), G_CALLBACK(gaim_gtkdialogs_remove_chat_cb),
 						_("Cancel"), NULL);
