@@ -585,7 +585,7 @@ theme_got_url(void *data, const char *themedata, size_t len)
 
 	theme_install_theme(path, data);
 
-	unlink(path);
+	g_unlink(path);
 	g_free(path);
 }
 
@@ -2267,13 +2267,14 @@ static void away_edit_sel (GtkWidget *dummy, void *tv)
 	struct away_message *amt;
 	GtkTreeIter iter;
 	GtkListStore *ls = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(tv)));
+	GtkTreeModel *model = GTK_TREE_MODEL(ls);
 	GtkTreeSelection *sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(tv));
 	GValue val = { 0, };
 
 	/* Get the pointer to the away message and pass that */
-	if (! gtk_tree_selection_get_selected (sel, (GtkTreeModel**)&ls, &iter))
+	if (! gtk_tree_selection_get_selected (sel, &model, &iter))
 		return;
-	gtk_tree_model_get_value (GTK_TREE_MODEL(ls), &iter, 1, &val);
+	gtk_tree_model_get_value (model, &iter, 1, &val);
 	amt = g_value_get_pointer (&val);
 	create_away_mess(NULL, amt);
 }
