@@ -1186,8 +1186,9 @@ gaim_gtk_request_fields(const char *title, const char *primary,
 
 				rows++;
 			}
-			else if (type == GAIM_REQUEST_FIELD_STRING &&
-					 gaim_request_field_string_is_multiline(field))
+			else if ((type == GAIM_REQUEST_FIELD_LIST) ||
+				 (type == GAIM_REQUEST_FIELD_STRING &&
+				  gaim_request_field_string_is_multiline(field)))
 			{
 				if (col_num > 0)
 					rows++;
@@ -1246,6 +1247,7 @@ gaim_gtk_request_fields(const char *title, const char *primary,
 					gtk_size_group_add_widget(sg, label);
 
 					if (type == GAIM_REQUEST_FIELD_LABEL ||
+					    type == GAIM_REQUEST_FIELD_LIST ||
 						(type == GAIM_REQUEST_FIELD_STRING &&
 						 gaim_request_field_string_is_multiline(field)))
 					{
@@ -1294,10 +1296,19 @@ gaim_gtk_request_fields(const char *title, const char *primary,
 									 GTK_FILL | GTK_EXPAND,
 									 5, 0);
 				}
-				else if (type != GAIM_REQUEST_FIELD_BOOLEAN)
+				else if (type == GAIM_REQUEST_FIELD_LIST)
+				{
+									gtk_table_attach(GTK_TABLE(table), widget,
+									0, 2 * cols,
+									row_num, row_num + 1,
+									GTK_FILL | GTK_EXPAND,
+									GTK_FILL | GTK_EXPAND,
+									5, 0);
+				}
+				else if (type == GAIM_REQUEST_FIELD_BOOLEAN)
 				{
 					gtk_table_attach(GTK_TABLE(table), widget,
-									 col_offset + 1, col_offset + 2,
+									 col_offset, col_offset + 1,
 									 row_num, row_num + 1,
 									 GTK_FILL | GTK_EXPAND,
 									 GTK_FILL | GTK_EXPAND,
@@ -1306,7 +1317,7 @@ gaim_gtk_request_fields(const char *title, const char *primary,
 				else
 				{
 					gtk_table_attach(GTK_TABLE(table), widget,
-									 col_offset, col_offset + 1,
+							 		 1, 2 * cols,
 									 row_num, row_num + 1,
 									 GTK_FILL | GTK_EXPAND,
 									 GTK_FILL | GTK_EXPAND,
@@ -1363,11 +1374,14 @@ gaim_gtk_request_fields(const char *title, const char *primary,
 static void
 file_yes_no_cb(GaimGtkRequestData *data, gint id)
 {
-	if (data->cbs[id] != NULL)
-		((GaimRequestFileCb)data->cbs[id])(data->user_data, data->u.file.name);
-
-	if (id == 1)
+	/* Only call the callback if yes was selected, otherwise the request
+	 * (eg. file transfer) will be cancelled, then when a new filename is chosen
+	 * things go BOOM */
+	if (id == 1) {
+		if (data->cbs[1] != NULL)
+			((GaimRequestFileCb)data->cbs[1])(data->user_data, data->u.file.name);
 		gaim_request_close(GAIM_REQUEST_FILE, data);
+	}
 }
 
 #if GTK_CHECK_VERSION(2,4,0) /* FILECHOOSER */
