@@ -22,7 +22,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include "gtkinternal.h"
+#include "internal.h"
+#include "gtkgaim.h"
 
 #ifndef _WIN32
 # include <X11/Xlib.h>
@@ -50,9 +51,9 @@
 #include "util.h"
 
 #include "gtkconv.h"
+#include "gtkdialogs.h"
 #include "gtkimhtml.h"
 #include "gtkutils.h"
-#include "ui.h"
 
 guint accels_save_timer = 0;
 
@@ -109,146 +110,6 @@ gaim_gtk_set_sensitive_if_input(GtkWidget *entry, GtkWidget *dialog)
 									  (*text != '\0'));
 }
 
-static int
-des_save_icon(GtkObject *obj, GdkEvent *e,
-			  GaimGtkConversation *gtkconv)
-{
-	gtk_widget_destroy(gtkconv->u.im->save_icon);
-	gtkconv->u.im->save_icon = NULL;
-
-	return TRUE;
-}
-
-static void
-do_save_icon(GtkObject *obj, GaimConversation *c)
-{
-	GaimGtkConversation *gtkconv;
-	FILE *file;
-	const char *f;
-	GaimBuddyIcon *icon;
-	size_t len;
-	const void *data;
-
-
-	gtkconv = GAIM_GTK_CONVERSATION(c);
-
-	f = gtk_file_selection_get_filename(
-		GTK_FILE_SELECTION(gtkconv->u.im->save_icon));
-
-	if (gaim_gtk_check_if_dir(f, GTK_FILE_SELECTION(gtkconv->u.im->save_icon)))
-		return;
-
-	icon = gaim_conv_im_get_icon(GAIM_CONV_IM(c));
-	data = gaim_buddy_icon_get_data(icon, &len);
-
-	if ((len > 0) && (data != NULL) && (file = fopen(f, "wb")) != NULL) {
-		fwrite(data, 1, len, file);
-		fclose(file);
-	} else {
-		gaim_notify_error(NULL, NULL,
-						  _("Can't save icon file to disk."), NULL);
-	}
-
-	gtk_widget_destroy(gtkconv->u.im->save_icon);
-	gtkconv->u.im->save_icon = NULL;
-}
-
-static void
-cancel_save_icon(GtkObject *obj, GaimGtkConversation *gtkconv)
-{
-	gtk_widget_destroy(gtkconv->u.im->save_icon);
-	gtkconv->u.im->save_icon = NULL;
-}
-
-
-void
-gaim_gtk_save_icon_dialog(GtkObject *obj, GaimConversation *conv)
-{
-	GaimGtkConversation *gtkconv;
-	char buf[BUF_LEN];
-
-	if (conv == NULL || gaim_conversation_get_type(conv) != GAIM_CONV_IM)
-		return;
-
-	if (!GAIM_IS_GTK_CONVERSATION(conv))
-		return;
-
-	gtkconv = GAIM_GTK_CONVERSATION(conv);
-
-	if (gtkconv->u.im->save_icon != NULL)
-	{
-		gdk_window_raise(gtkconv->u.im->save_icon->window);
-		return;
-	}
-
-	gtkconv->u.im->save_icon = gtk_file_selection_new(_("Save Icon"));
-
-	gtk_file_selection_hide_fileop_buttons(
-		GTK_FILE_SELECTION(gtkconv->u.im->save_icon));
-
-	g_snprintf(buf, BUF_LEN - 1,
-			   "%s" G_DIR_SEPARATOR_S "%s.icon",
-			   gaim_home_dir(), gaim_conversation_get_name(conv));
-
-	gtk_file_selection_set_filename(
-		GTK_FILE_SELECTION(gtkconv->u.im->save_icon), buf);
-
-	g_signal_connect(G_OBJECT(gtkconv->u.im->save_icon), "delete_event",
-					 G_CALLBACK(des_save_icon), gtkconv);
-	g_signal_connect(G_OBJECT(GTK_FILE_SELECTION(gtkconv->u.im->save_icon)->ok_button), "clicked",
-					 G_CALLBACK(do_save_icon), conv);
-	g_signal_connect(G_OBJECT(GTK_FILE_SELECTION(gtkconv->u.im->save_icon)->cancel_button), "clicked",
-					 G_CALLBACK(cancel_save_icon), gtkconv);
-
-	gtk_widget_show(gtkconv->u.im->save_icon);
-}
-
-int
-gaim_gtk_get_dispstyle(GaimConversationType type)
-{
-	int dispstyle = 2;
-	int value;
-
-	if (type == GAIM_CONV_CHAT) {
-		value = gaim_prefs_get_int("/gaim/gtk/conversations/chat/button_type");
-
-		switch (value) {
-			case GAIM_BUTTON_TEXT:  dispstyle = 1; break;
-			case GAIM_BUTTON_IMAGE: dispstyle = 0; break;
-			default:                dispstyle = 2; break; /* both/neither */
-		}
-	}
-	else if (type == GAIM_CONV_IM) {
-		value = gaim_prefs_get_int("/gaim/gtk/conversations/im/button_type");
-
-		switch (value) {
-			case GAIM_BUTTON_TEXT:  dispstyle = 1; break;
-			case GAIM_BUTTON_IMAGE: dispstyle = 0; break;
-			default:                dispstyle = 2; break; /* both/neither */
-		}
-	}
-
-	return dispstyle;
-}
-
-GtkWidget *
-gaim_gtk_change_text(const char *text, GtkWidget *button,
-					 const char *stock, GaimConversationType type)
-{
-	int dispstyle = gaim_gtk_get_dispstyle(type);
-
-	if (button != NULL)
-		gtk_widget_destroy(button);
-
-	button = gaim_pixbuf_button_from_stock((dispstyle == 0 ? NULL : text),
-										   (dispstyle == 1 ? NULL : stock),
-										   GAIM_BUTTON_VERTICAL);
-
-	gtk_widget_show(button);
-
-	return button;
-}
-
 void
 gaim_gtk_toggle_sensitive(GtkWidget *widget, GtkWidget *to_toggle)
 {
@@ -346,7 +207,7 @@ GtkWidget *gaim_new_check_item(GtkWidget *menu, const char *str,
 GtkWidget *
 gaim_pixbuf_toolbar_button_from_stock(const char *icon)
 {
-	GtkWidget *button, *image,  *bbox;
+	GtkWidget *button, *image, *bbox;
 
 	button = gtk_toggle_button_new();
 	gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
@@ -367,36 +228,36 @@ GtkWidget *
 gaim_pixbuf_button_from_stock(const char *text, const char *icon,
 							  GaimButtonOrientation style)
 {
-	GtkWidget *button, *image, *label, *bbox, *ibox, *lbox;
+	GtkWidget *button, *image, *label, *bbox, *ibox, *lbox = NULL;
 
 	button = gtk_button_new();
 
 	if (style == GAIM_BUTTON_HORIZONTAL) {
-			bbox = gtk_hbox_new(FALSE, 5);
-			ibox = gtk_hbox_new(FALSE, 0);
+		bbox = gtk_hbox_new(FALSE, 0);
+		ibox = gtk_hbox_new(FALSE, 0);
+		if (text)
 			lbox = gtk_hbox_new(FALSE, 0);
-	}
-	else {
-			bbox = gtk_vbox_new(FALSE, 5);
-			ibox = gtk_vbox_new(FALSE, 0);
+	} else {
+		bbox = gtk_vbox_new(FALSE, 0);
+		ibox = gtk_vbox_new(FALSE, 0);
+		if (text)
 			lbox = gtk_vbox_new(FALSE, 0);
 	}
 
-	gtk_container_add (GTK_CONTAINER(button), bbox);
-
-	gtk_box_pack_start_defaults(GTK_BOX(bbox), ibox);
-	gtk_box_pack_start_defaults(GTK_BOX(bbox), lbox);
+	gtk_container_add(GTK_CONTAINER(button), bbox);
 
 	if (icon) {
+		gtk_box_pack_start_defaults(GTK_BOX(bbox), ibox);
 		image = gtk_image_new_from_stock(icon, GTK_ICON_SIZE_BUTTON);
-		gtk_box_pack_end(GTK_BOX(ibox), image, FALSE, FALSE, 0);
+		gtk_box_pack_end(GTK_BOX(ibox), image, FALSE, TRUE, 0);
 	}
 
 	if (text) {
+		gtk_box_pack_start_defaults(GTK_BOX(bbox), lbox);
 		label = gtk_label_new(NULL);
 		gtk_label_set_text_with_mnemonic(GTK_LABEL(label), text);
 		gtk_label_set_mnemonic_widget(GTK_LABEL(label), button);
-		gtk_box_pack_start(GTK_BOX(lbox), label, FALSE, FALSE, 0);
+		gtk_box_pack_start(GTK_BOX(lbox), label, FALSE, TRUE, 0);
 		gaim_set_accessible_label (button, label);
 	}
 
@@ -728,8 +589,8 @@ create_account_menu(GtkWidget *optmenu, GaimAccount *default_account,
 		gtk_widget_show(image);
 
 		g_snprintf(buf, sizeof(buf), "%s (%s)",
-				   gaim_account_get_username(account), 
-				   (plugin != NULL) ? plugin->info->name : _("Unknown"));
+				   gaim_account_get_username(account),
+				   gaim_account_get_protocol_name(account));
 
 		/* Create the label. */
 		label = gtk_label_new(buf);
@@ -802,6 +663,33 @@ account_menu_destroyed_cb(GtkWidget *optmenu, GdkEvent *event,
 	return FALSE;
 }
 
+void
+gaim_gtk_account_option_menu_set_selected(GtkWidget *optmenu, GaimAccount *account)
+{
+	GtkWidget *menu;
+	GtkWidget *item;
+	gboolean show_all;
+	GaimAccount *curaccount;
+	GaimFilterAccountFunc filter_func;
+
+	menu = gtk_option_menu_get_menu(GTK_OPTION_MENU(optmenu));
+	item = gtk_menu_get_active(GTK_MENU(menu));
+	curaccount = g_object_get_data(G_OBJECT(item), "account");
+
+	if (account == curaccount)
+		return;
+
+	show_all = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(optmenu),
+												 "show_all"));
+
+	filter_func = g_object_get_data(G_OBJECT(optmenu),
+										   "filter_func");
+
+	gtk_option_menu_remove_menu(GTK_OPTION_MENU(optmenu));
+
+	create_account_menu(optmenu, account, filter_func, show_all);
+}
+
 GtkWidget *
 gaim_gtk_account_option_menu_new(GaimAccount *default_account,
 								 gboolean show_all, GCallback cb,
@@ -854,8 +742,8 @@ gaim_gtk_check_if_dir(const char *path, GtkFileSelection *filesel)
 
 	if (g_file_test(path, G_FILE_TEST_IS_DIR)) {
 		/* append a / if needed */
-		if (path[strlen(path) - 1] != '/') {
-			dirname = g_strconcat(path, "/", NULL);
+		if (path[strlen(path) - 1] != G_DIR_SEPARATOR) {
+			dirname = g_strconcat(path, G_DIR_SEPARATOR_S, NULL);
 		} else {
 			dirname = g_strdup(path);
 		}
@@ -1341,7 +1229,7 @@ gaim_gtk_menu_position_func(GtkMenu *menu,
 			*y = *y - ythickness;
 		else
 			*y = *y + ythickness - requisition.height + 1;
-	  
+ 
 		*y = CLAMP (*y, monitor.y,
 			   monitor.y + monitor.height - requisition.height);
 	}
@@ -1384,3 +1272,15 @@ gaim_gtk_treeview_popup_menu_position_func(GtkMenu *menu,
 	gaim_gtk_menu_position_func (menu, x, y, push_in, data);
 #endif
 }
+
+gboolean
+gaim_running_gnome(void)
+{
+	if ((g_getenv("GNOME_DESKTOP_SESSION_ID") != NULL) &&
+		(g_find_program_in_path("gnome-open") != NULL))
+	{
+		return TRUE;
+	}
+
+	return FALSE;
+}
