@@ -173,17 +173,25 @@ int gaim_log_get_total_size(GaimLogType type, const char *name, GaimAccount *acc
 	return size;
 }
 
-static char* gaim_log_get_log_dir(GaimLogType type, const char *name, GaimAccount *account) {
-	char *acct_name = g_strdup(gaim_escape_filename(gaim_normalize(account,
-				gaim_account_get_username(account))));
+static char *
+gaim_log_get_log_dir(GaimLogType type, const char *name, GaimAccount *account)
+{
+	GaimPlugin *prpl;
+	GaimPluginProtocolInfo *prpl_info;
+	const char *prpl_name;
+	char *acct_name;
 	const char *target;
-	/* does this seem like a bad way to get this component of the path to anyone else? --Nathan */
-	const char *prpl = GAIM_PLUGIN_PROTOCOL_INFO(
-			gaim_find_prpl(gaim_account_get_protocol_id(account))
-			)->list_icon(account, NULL);
-
 	char *dir;
 
+	prpl = gaim_find_prpl(gaim_account_get_protocol_id(account));
+	if (!prpl)
+		return NULL;
+	prpl_info = GAIM_PLUGIN_PROTOCOL_INFO(prpl);
+	prpl_name = prpl_info->list_icon(account, NULL);
+
+	acct_name = g_strdup(gaim_escape_filename(gaim_normalize(account,
+				gaim_account_get_username(account))));
+
 	if (type == GAIM_LOG_CHAT) {
 		char *temp = g_strdup_printf("%s.chat", gaim_normalize(account, name));
 		target = gaim_escape_filename(temp);
@@ -194,10 +202,10 @@ static char* gaim_log_get_log_dir(GaimLogType type, const char *name, GaimAccoun
 		target = gaim_escape_filename(gaim_normalize(account, name));
 	}
 
-
-	dir = g_build_filename(gaim_user_dir(), "logs", prpl, acct_name, target, NULL);
+	dir = g_build_filename(gaim_user_dir(), "logs", prpl_name, acct_name, target, NULL);
 
 	g_free(acct_name);
+
 	return dir;
 }
 
@@ -367,8 +375,11 @@ static void log_writer_common(GaimLog *log, GaimMessageFlags type,
 	if(!data) {
 		/* This log is new */
 		char *dir, *filename, *path;
-		
+
 		dir = gaim_log_get_log_dir(log->type, log->name, log->account);
+		if (dir == NULL)
+			return;
+
 		gaim_build_dir (dir, S_IRUSR | S_IWUSR | S_IXUSR);
 
 		strftime(date, sizeof(date), "%Y-%m-%d.%H%M%S", localtime(&log->time));
@@ -381,7 +392,7 @@ static void log_writer_common(GaimLog *log, GaimMessageFlags type,
 
 		log->logger_data = data = g_new0(struct generic_logger_data, 1);
 
-		data->file = fopen(path, "a");
+		data->file = g_fopen(path, "a");
 		if (!data->file) {
 			gaim_debug(GAIM_DEBUG_ERROR, "log",
 					"Could not create log file %s\n", path);
@@ -389,7 +400,7 @@ static void log_writer_common(GaimLog *log, GaimMessageFlags type,
 			return;
 		}
 		g_free(path);
-	}	
+	}
 }
 
 static GList *log_lister_common(GaimLogType type, const char *name, GaimAccount *account, const char *ext, GaimLogLogger *logger)
@@ -403,6 +414,8 @@ static GList *log_lister_common(GaimLogType type, const char *name, GaimAccount
 		return NULL;
 
 	path = gaim_log_get_log_dir(type, name, account);
+	if (path == NULL)
+		return NULL;
 
 	if (!(dir = g_dir_open(path, 0, NULL))) {
 		g_free(path);
@@ -434,7 +447,7 @@ int log_sizer_common(GaimLog *log)
 	struct stat st;
 	struct generic_logger_data *data = log->logger_data;
 
-	if (!data->path || stat(data->path, &st))
+	if (!data->path || g_stat(data->path, &st))
 		st.st_size = 0;
 
 	return st.st_size;
@@ -458,6 +471,7 @@ static void xml_logger_write(GaimLog *log,
 {
 	char date[64];
 	char *xhtml = NULL;
+
 	if (!log->logger_data) {
 		/* This log is new.  We could use the loggers 'new' function, but
 		 * creating a new file there would result in empty files in the case
@@ -465,6 +479,10 @@ static void xml_logger_write(GaimLog *log,
 		 */
 		char *dir = gaim_log_get_log_dir(log->type, log->name, log->account);
 		FILE *file;
+
+		if (dir == NULL)
+			return;
+
 		strftime(date, sizeof(date), "%Y-%m-%d.%H%M%S.xml", localtime(&log->time));
 
 		gaim_build_dir (dir, S_IRUSR | S_IWUSR | S_IXUSR);
@@ -472,7 +490,7 @@ static void xml_logger_write(GaimLog *log,
 		char *filename = g_build_filename(dir, date, NULL);
 		g_free(dir);
 
-		log->logger_data = fopen(filename, "a");
+		log->logger_data = g_fopen(filename, "a");
 		if (!log->logger_data) {
 			gaim_debug(GAIM_DEBUG_ERROR, "log", "Could not create log file %s\n", filename);
 			g_free(filename);
@@ -833,7 +851,7 @@ static GList *old_logger_list(GaimLogType type, const char *sn, GaimAccount *acc
 	g_free(logfile);
 	g_free(pathstr);
 
-	if (!(file = fopen(gaim_stringref_value(pathref), "rb"))) {
+	if (!(file = g_fopen(gaim_stringref_value(pathref), "rb"))) {
 		gaim_stringref_unref(pathref);
 		return NULL;
 	}
@@ -944,7 +962,7 @@ static int old_logger_total_size(GaimLogType type, const char *name, GaimAccount
 	int size;
 	struct stat st;
 
-	if (stat(pathstr, &st))
+	if (g_stat(pathstr, &st))
 		size = 0;
 	else
 		size = st.st_size;
@@ -958,8 +976,8 @@ static int old_logger_total_size(GaimLogType type, const char *name, GaimAccount
 static char * old_logger_read (GaimLog *log, GaimLogReadFlags *flags)
 {
 	struct old_logger_data *data = log->logger_data;
-	FILE *file = fopen(gaim_stringref_value(data->pathref), "rb");
-	char *read = g_malloc(data->length + 1);
+	FILE *file = g_fopen(gaim_stringref_value(data->pathref), "rb");
+	char *tmp, *read = g_malloc(data->length + 1);
 	fseek(file, data->offset, SEEK_SET);
 	fread(read, data->length, 1, file);
 	fclose(file);
@@ -967,6 +985,11 @@ static char * old_logger_read (GaimLog *log, GaimLogReadFlags *flags)
 	*flags = 0;
 	if(strstr(read, "<BR>"))
 		*flags |= GAIM_LOG_READ_NO_NEWLINE;
+	else {
+		tmp = g_markup_escape_text(read, -1);
+		g_free(read);
+		read = tmp;
+	}
 	return read;
 }
 
