@@ -1,4 +1,4 @@
-/* $Id: libgg.c,v 1.21 2004/08/25 03:09:08 thekingant Exp $ */
+/* $Id: libgg.c,v 1.21.2.1 2005/03/02 11:53:57 nosnilmot Exp $ */
 
 /*
  *  (C) Copyright 2001 Wojtek Kaniewski <wojtekka@irc.pl>,
@@ -70,7 +70,7 @@ static char rcsid[]
 #ifdef __GNUC__
 __attribute__ ((unused))
 #endif
-= "$Id: libgg.c,v 1.21 2004/08/25 03:09:08 thekingant Exp $";
+= "$Id: libgg.c,v 1.21.2.1 2005/03/02 11:53:57 nosnilmot Exp $";
 
 #endif 
 
@@ -1055,7 +1055,7 @@ static int gg_watch_fd_connected(struct gg_session *sess, struct gg_event *e)
 
 		if (h->length >= sizeof(*s)) {
 			e->type = GG_EVENT_STATUS;
-			memcpy(&e->event.status, p, h->length);
+			memcpy(&e->event.status, p, sizeof(*s));
 			e->event.status.uin = fix32(e->event.status.uin);
 			e->event.status.status = fix32(e->event.status.status);
 		}
