@@ -54,6 +54,91 @@ static void yahoo_add_buddy(GaimConnection *gc, GaimBuddy *, GaimGroup *);
 static void yahoo_login_page_cb(void *user_data, const char *buf, size_t len);
 
 
+static void
+yahoo_add_permit(GaimConnection *gc, const char *who)
+{
+	gaim_debug_info("yahoo",
+			"Permitting ID %s local contact rights for account %s\n", who, gc->account);	
+	gaim_privacy_permit_add(gc->account,who,TRUE);
+}
+
+static void
+yahoo_rem_permit(GaimConnection *gc, const char *who)
+{
+	gaim_debug_info("yahoo",
+			"Denying ID %s local contact rights for account %s\n", who, gc->account);	
+	gaim_privacy_permit_remove(gc->account,who,TRUE);
+}
+
+gboolean yahoo_privacy_check(GaimConnection *gc, const char *who)
+{
+	/* returns TRUE if allowed through, FALSE otherwise */
+	GSList *list;
+	gboolean permitted=FALSE;
+
+	switch (gc->account->perm_deny) {
+		case 0:
+			gaim_debug_warning("yahoo", "Privacy setting was 0.  If you can "
+							   "reproduce this, please file a bug report.\n");
+			permitted = TRUE;
+			break;
+
+		case GAIM_PRIVACY_ALLOW_ALL:
+			permitted = TRUE;
+			break;
+
+		case GAIM_PRIVACY_DENY_ALL:
+			gaim_debug_info("yahoo",
+			    "%s blocked data received from %s (GAIM_PRIVACY_DENY_ALL)\n",
+			    gc->account->username,who);
+			break;
+
+		case GAIM_PRIVACY_ALLOW_USERS:
+			for( list=gc->account->permit; list!=NULL; list=list->next ) {
+				if ( !gaim_utf8_strcasecmp(who, gaim_normalize(gc->account, (char *)list->data)) ) {
+					permitted=TRUE;
+					gaim_debug_info("yahoo",
+					    "%s allowed data received from %s (GAIM_PRIVACY_ALLOW_USERS)\n",
+					    gc->account->username,who);
+					break;
+				}
+			}
+			break;
+
+		case GAIM_PRIVACY_DENY_USERS:
+			/* seeing we're letting everyone through, except the deny list*/
+			permitted=TRUE;
+			for( list=gc->account->deny; list!=NULL; list=list->next ) {
+				if ( !gaim_utf8_strcasecmp(who, gaim_normalize( gc->account, (char *)list->data )) ) {
+					permitted=FALSE;
+					gaim_debug_info("yahoo",
+					    "%s blocked data received from %s (GAIM_PRIVACY_DENY_USERS)\n",
+					    gc->account->username,who);
+					}
+				break;
+			}
+			break;
+
+		case GAIM_PRIVACY_ALLOW_BUDDYLIST:
+			if ( gaim_find_buddy(gc->account,who) != NULL ) {
+				permitted = TRUE;
+			} else {
+				gaim_debug_info("yahoo",
+				    "%s blocked data received from %s (GAIM_PRIVACY_ALLOW_BUDDYLIST)\n",
+				    gc->account->username,who);
+			}
+		break;
+
+		default:
+			gaim_debug_warning("yahoo", "Privacy setting was unknown.  If you can "
+							   "reproduce this, please file a bug report.\n");
+			permitted = FALSE;
+			break;
+	}
+
+	return permitted;
+}
+
 struct yahoo_packet *yahoo_packet_new(enum yahoo_service service, enum yahoo_status status, int id)
 {
 	struct yahoo_packet *pkt = g_new0(struct yahoo_packet, 1);
@@ -373,6 +458,9 @@ static void yahoo_process_status(GaimConnection *gc, struct yahoo_packet *pkt)
 		case 8: /* how many online buddies we have */
 			break;
 		case 7: /* the current buddy */
+			if (name && f) /* update the last buddy before setting a new one */
+				yahoo_update_status(gc, name, f);
+
 			name = pair->value;
 			if (name && g_utf8_validate(name, -1, NULL))
 				f = yahoo_friend_find_or_new(gc, name);
@@ -448,9 +536,6 @@ static void yahoo_process_status(GaimConnection *gc, struct yahoo_packet *pkt)
 				serv_got_update(gc, name, FALSE, 0, 0, 0, 0);
 				break;
 			}
-
-			if (f)
-				yahoo_update_status(gc, name, f);
 			break;
 		case 60: /* SMS */
 			if (f) {
@@ -517,6 +602,11 @@ static void yahoo_process_status(GaimConnection *gc, struct yahoo_packet *pkt)
 
 		l = l->next;
 	}
+
+	if (name && f) /* there's not a next buddy after the last buddy,
+	                  so this does for the last buddy what case 7 does
+	                  for all the rest */
+		yahoo_update_status(gc, name, f);
 }
 
 static void yahoo_do_group_check(GaimAccount *account, GHashTable *ht, const char *name, const char *group)
@@ -718,10 +808,15 @@ static void yahoo_process_list(GaimConnection *gc, struct yahoo_packet *pkt)
 		yd->tmp_serv_ilist = NULL;
 	}
 
-	if (got_serv_list) {
-		gc->account->perm_deny = 4;
-		serv_set_permit_deny(gc);
+	if (got_serv_list &&
+		((gc->account->perm_deny != GAIM_PRIVACY_ALLOW_BUDDYLIST) &&
+		(gc->account->perm_deny != GAIM_PRIVACY_DENY_ALL) &&
+		(gc->account->perm_deny != GAIM_PRIVACY_ALLOW_USERS)))
+	{
+		gc->account->perm_deny = GAIM_PRIVACY_DENY_USERS;
+		gaim_debug_info("yahoo", "Privacy defaulting to GAIM_PRIVACY_DENY_USERS.\n", gc->account->username);
 	}
+
 }
 
 static void yahoo_process_notify(GaimConnection *gc, struct yahoo_packet *pkt)
@@ -749,7 +844,8 @@ static void yahoo_process_notify(GaimConnection *gc, struct yahoo_packet *pkt)
 	if (!from || !msg)
 		return;
 
-	if (!g_ascii_strncasecmp(msg, "TYPING", strlen("TYPING"))) {
+	if (!g_ascii_strncasecmp(msg, "TYPING", strlen("TYPING"))
+		&& (yahoo_privacy_check(gc, from)))  {
 		if (*stat == '1')
 			serv_got_typing(gc, from, 0, GAIM_TYPING);
 		else
@@ -831,6 +927,11 @@ static void yahoo_process_message(GaimConnection *gc, struct yahoo_packet *pkt)
 			continue;
 		}
 
+		if (!yahoo_privacy_check(gc, im->from)) {
+			gaim_debug_info("yahoo", "Message from %s dropped.\n", im->from);
+			continue;
+		}
+
 		m = yahoo_string_decode(gc, im->msg, im->utf8);
 		gaim_str_strip_cr(m);
 
@@ -2018,7 +2119,10 @@ static void yahoo_process_audible(GaimConnection *gc, struct yahoo_packet *pkt)
 		gaim_debug_misc("yahoo", "Warning, nonutf8 audible, ignoring!\n");
 		return;
 	}
-
+	if (!yahoo_privacy_check(gc, who)) {
+		gaim_debug_misc("yahoo", "Audible message from %s for %s dropped!\n", gc->account->username, who);
+		return;
+	}
 	serv_got_im(gc, who, msg, 0, time(NULL));
 }
 
@@ -2161,6 +2265,26 @@ static void yahoo_pending(gpointer data, gint source, GaimInputCondition cond)
 		if (yd->rxlen < YAHOO_PACKET_HDRLEN)
 			return;
 
+		if (strncmp(yd->rxqueue, "YMSG", MIN(4, yd->rxlen)) != 0) {
+			/* HEY! This isn't even a YMSG packet. What
+			 * are you trying to pull? */
+			guchar *start;
+
+			gaim_debug_warning("yahoo", "Error in YMSG stream, got something not a YMSG packet!\n");
+
+			start = memchr(yd->rxqueue + 1, 'Y', yd->rxlen - 1);
+			if (start) {
+				g_memmove(yd->rxqueue, start, yd->rxlen - (start - yd->rxqueue));
+				yd->rxlen -= start - yd->rxqueue;
+				continue;
+			} else {
+				g_free(yd->rxqueue);
+				yd->rxqueue = NULL;
+				yd->rxlen = 0;
+				return;
+			}
+		}
+
 		pos += 4; /* YMSG */
 		pos += 2;
 		pos += 2;
@@ -2360,7 +2484,7 @@ static void yahoo_login_page_cb(void *user_data, const char *buf, size_t len)
 	const char *sn = gaim_account_get_username(account);
 	const char *pass = gaim_account_get_password(account);
 	GHashTable *hash = yahoo_login_page_hash(buf, len);
-	GString *url = g_string_new("GET /config/login?login=");
+	GString *url = g_string_new("GET http://login.yahoo.com/config/login?login=");
 	char md5[33], *hashp = md5, *chal;
 	int i;
 	md5_byte_t result[16];
@@ -3259,6 +3383,7 @@ static void yahoo_change_buddys_group(GaimConnection *gc, const char *who,
 	yahoo_send_packet(yd, pkt);
 	yahoo_packet_free(pkt);
 
+#if 0
 	/* Step 2:  Remove buddy from old group */
 	pkt = yahoo_packet_new(YAHOO_SERVICE_REMBUDDY, YAHOO_STATUS_AVAILABLE, 0);
 	yahoo_packet_hash(pkt, 1, gaim_connection_get_display_name(gc));
@@ -3266,6 +3391,7 @@ static void yahoo_change_buddys_group(GaimConnection *gc, const char *who,
 	yahoo_packet_hash(pkt, 65, gpo);
 	yahoo_send_packet(yd, pkt);
 	yahoo_packet_free(pkt);
+#endif
 	g_free(gpn);
 	g_free(gpo);
 }
@@ -3324,9 +3450,9 @@ static GaimPluginProtocolInfo prpl_info =
 	NULL, /* add_buddies */
 	yahoo_remove_buddy,
 	NULL, /*remove_buddies */
-	NULL, /* add_permit */
+	yahoo_add_permit,
 	yahoo_add_deny,
-	NULL, /* rem_permit */
+	yahoo_rem_permit,
 	yahoo_rem_deny,
 	yahoo_set_permit_deny,
 	NULL, /* warn */
