@@ -32,6 +32,7 @@
 
 #include "debug.h"
 #include "prpl.h"
+#include "privacy.h"
 
 #include "conversation.h"
 #include "notify.h"
@@ -157,6 +158,11 @@ void yahoo_process_conference_invite(GaimConnection *gc, struct yahoo_packet *pk
 	if (members) {
 		g_hash_table_replace(components, g_strdup("members"), g_strdup(members->str));
 	}
+	if (!yahoo_privacy_check(gc, who)) {
+		gaim_debug_info("yahoo",
+		    "Invite to conference %s from %s has been dropped.\n", room, who);
+		return;
+	}
 	serv_got_chat_invite(gc, room, who, msg, components);
 
 	g_string_free(members, TRUE);
@@ -335,10 +341,13 @@ void yahoo_process_chat_logout(GaimConnection *gc, struct yahoo_packet *pkt)
 
 void yahoo_process_chat_join(GaimConnection *gc, struct yahoo_packet *pkt)
 {
+	GaimAccount *account = gaim_connection_get_account(gc);
 	struct yahoo_data *yd = (struct yahoo_data *) gc->proto_data;
 	GaimConversation *c = NULL;
 	GSList *l;
 	GList *members = NULL;
+	GList *roomies = NULL;
+	GaimConversationUiOps *ops;
 	char *room = NULL;
 	char *topic = NULL;
 	char *someid, *someotherid, *somebase64orhashosomething, *somenegativenumber;
@@ -437,6 +446,18 @@ void yahoo_process_chat_join(GaimConnection *gc, struct yahoo_packet *pkt)
 		yahoo_chat_add_users(GAIM_CONV_CHAT(c), members);
 	}
 
+	ops = gaim_conversation_get_ui_ops(c);
+
+	for (l = account->deny; l != NULL; l = l->next) {
+		for (roomies = members; roomies; roomies = roomies->next) {
+			if (!gaim_utf8_strcasecmp((char *)l->data, roomies->data)) {
+				gaim_debug_info("yahoo", "Ignoring room member %s in room %s\n" ,roomies->data, room);
+				gaim_conv_chat_ignore(GAIM_CONV_CHAT(c),roomies->data);
+				ops->chat_update_user((c), roomies->data);
+			}
+		}
+	}
+	g_list_free(roomies);
 	g_list_free(members);
 	g_free(room);
 	if (topic)
@@ -565,6 +586,11 @@ void yahoo_process_chat_addinvite(GaimConnection *gc, struct yahoo_packet *pkt)
 
 		components = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_free);
 		g_hash_table_replace(components, g_strdup("room"), g_strdup(room));
+		if (!yahoo_privacy_check(gc, who)) {
+			gaim_debug_info("yahoo",
+			"Invite to room %s from %s has been dropped.\n", room, who);
+			return;
+		}
 		serv_got_chat_invite(gc, room, who, msg, components);
 	}
 	if (room)
@@ -1362,7 +1388,8 @@ static void yahoo_roomlist_got_connected(gpointer data, gint source, GaimInputCo
 	yrl->fd = source;
 
 	cookie = g_strdup_printf("Y=%s; T=%s", yd->cookie_y, yd->cookie_t);
-	buf = g_strdup_printf("GET /%s HTTP/1.0\r\nHost: %s\r\nCookie: %s\r\n\r\n", yrl->path, yrl->host, cookie);
+	buf = g_strdup_printf("GET http://%s/%s HTTP/1.0\r\nHost: %s\r\nCookie: %s\r\n\r\n",
+						  yrl->host, yrl->path, yrl->host, cookie);
 	write(yrl->fd, buf, strlen(buf));
 	g_free(cookie);
 	g_free(buf);
@@ -1435,7 +1462,7 @@ void yahoo_roomlist_cancel(GaimRoomlist *list)
 
 	for (; l; l = l->next) {
 		yahoo_roomlist_destroy(l->data);
-		gaim_roomlist_unref(l->data);
+		gaim_roomlist_unref(list);
 	}
 	g_list_free(k);
 }
@@ -1475,6 +1502,7 @@ void yahoo_roomlist_expand_category(GaimRoomlist *list, GaimRoomlistRoom *catego
 	{
 		gaim_notify_error(gaim_account_get_connection(list->account),
 		                  NULL, _("Connection problem"), _("Unable to fetch room list."));
+		gaim_roomlist_ref(list);
 		yahoo_roomlist_cleanup(list, yrl);
 		return;
 	}
