@@ -35,6 +35,7 @@
 #include "prefs.h"
 #include "proxy.h"
 #include "util.h"
+#include "md5.h"
 
 #include "gaim.h"
 
@@ -420,7 +421,7 @@ static void cope_with_gdb_brokenness()
 static void
 gaim_dns_childthread(int child_out, int child_in, dns_params_t *dns_params, gboolean show_debug)
 {
-	const int zero = 0;
+	const size_t zero = 0;
 	int rc;
 #if HAVE_GETADDRINFO
 	struct addrinfo hints, *res, *tmp;
@@ -481,8 +482,8 @@ gaim_dns_childthread(int child_out, int child_in, dns_params_t *dns_params, gboo
 		 */
 		hints.ai_socktype = SOCK_STREAM;
 		rc = getaddrinfo(dns_params->hostname, servname, &hints, &res);
+		write(child_out, &rc, sizeof(rc));
 		if (rc) {
-			write(child_out, &rc, sizeof(int));
 			close(child_out);
 			if (show_debug)
 				fprintf(stderr,"dns[%d] Error: getaddrinfo returned %d\n",
@@ -490,7 +491,6 @@ gaim_dns_childthread(int child_out, int child_in, dns_params_t *dns_params, gboo
 			dns_params->hostname[0] = '\0';
 			continue;
 		}
-		write(child_out, &zero, sizeof(zero));
 		tmp = res;
 		while(res) {
 			size_t ai_addrlen = res->ai_addrlen;
@@ -501,7 +501,7 @@ gaim_dns_childthread(int child_out, int child_in, dns_params_t *dns_params, gboo
 		freeaddrinfo(tmp);
 		write(child_out, &zero, sizeof(zero));
 #else
-		if (!inet_aton(hostname, &sin.sin_addr)) {
+		if (!inet_aton(dns_params->hostname, &sin.sin_addr)) {
 			struct hostent *hp;
 			if (!(hp = gethostbyname(dns_params->hostname))) {
 				write(child_out, &h_errno, sizeof(int));
@@ -516,8 +516,9 @@ gaim_dns_childthread(int child_out, int child_in, dns_params_t *dns_params, gboo
 		} else
 			sin.sin_family = AF_INET;
 
+		rc = 0;
+		write(child_out, &rc, sizeof(rc));
 		sin.sin_port = htons(dns_params->port);
-		write(child_out, &zero, sizeof(zero));
 		write(child_out, &addrlen, sizeof(addrlen));
 		write(child_out, &sin, addrlen);
 		write(child_out, &zero, sizeof(zero));
@@ -649,8 +650,12 @@ typedef struct _dns_tdata {
 
 static gboolean dns_main_thread_cb(gpointer data) {
 	dns_tdata *td = (dns_tdata*)data;
+	if (td->errmsg != NULL) {
+		gaim_debug_info("dns", "%s\n", td->errmsg);
+	}
 	td->callback(td->hosts, td->data, td->errmsg);
 	g_free(td->hostname);
+	g_free(td->errmsg);
 	g_free(td);
 	return FALSE;
 }
@@ -660,22 +665,22 @@ static gpointer dns_thread(gpointer data) {
 	dns_tdata *td = (dns_tdata*)data;
 	struct hostent *hp;
 
-	if(!(hp = gethostbyname(td->hostname)))
-		goto failure;
-	memset(&sin, 0, sizeof(struct sockaddr_in));
-	memcpy(&sin.sin_addr.s_addr, hp->h_addr, hp->h_length);
-	sin.sin_family = hp->h_addrtype;
-	sin.sin_port = htons(td->port);
+	if ((hp = gethostbyname(td->hostname))) {
+		memset(&sin, 0, sizeof(struct sockaddr_in));
+		memcpy(&sin.sin_addr.s_addr, hp->h_addr, hp->h_length);
+		sin.sin_family = hp->h_addrtype;
+		sin.sin_port = htons(td->port);
 
-	td->hosts = g_slist_append(td->hosts, GINT_TO_POINTER(sizeof(sin)));
-	td->hosts = g_slist_append(td->hosts, g_memdup(&sin, sizeof(sin)));
+		td->hosts = g_slist_append(td->hosts,
+				GINT_TO_POINTER(sizeof(sin)));
+		td->hosts = g_slist_append(td->hosts,
+				g_memdup(&sin, sizeof(sin)));
+	} else {
+		td->errmsg = g_strdup_printf("DNS error: %d", errno);
+	}
 	/* back to main thread */
 	g_idle_add(dns_main_thread_cb, td);
 	return 0;
- failure:
-	g_free(td->hostname);
-	g_free(td);
-	return 0;
 } 
 
 int gaim_gethostbyname_async(const char *hostname, int port,
@@ -1131,7 +1136,14 @@ s4_canwrite(gpointer data, gint source, GaimInputCondition cond)
 	}
 	fcntl(source, F_SETFL, 0);
 
-	/* XXX does socks4 not support host name lookups by the proxy? */
+	/*
+	 * The socks4 spec doesn't include support for doing host name
+	 * lookups by the proxy.  Some socks4 servers do this via
+	 * extensions to the protocol.  Since we don't know if a
+	 * server supports this, it would need to be implemented
+	 * with an option, or some detection mechanism - in the
+	 * meantime, stick with plain old SOCKS4.
+	 */
 	if (!(hp = gethostbyname(phb->host))) {
 		close(source);
 
@@ -1278,10 +1290,10 @@ s5_sendconnect(gpointer data, gint source)
 	buf[3] = 0x03;		/* address type -- host name */
 	buf[4] = hlen;
 	memcpy(buf + 5, phb->host, hlen);
-	buf[5 + strlen(phb->host)] = phb->port >> 8;
-	buf[5 + strlen(phb->host) + 1] = phb->port & 0xff;
+	buf[5 + hlen] = phb->port >> 8;
+	buf[5 + hlen + 1] = phb->port & 0xff;
 
-	if (write(source, buf, (5 + strlen(phb->host) + 2)) < (5 + strlen(phb->host) + 2)) {
+	if (write(source, buf, (5 + hlen + 2)) < (5 + hlen + 2)) {
 		close(source);
 
 		try_connect(phb);
@@ -1317,6 +1329,142 @@ s5_readauth(gpointer data, gint source, GaimInputCondition cond)
 	s5_sendconnect(phb, source);
 }
 
+static void hmacmd5_chap(const unsigned char * challenge, int challen, const char * passwd, unsigned char * response)
+{
+	int i;
+	unsigned char Kxoripad[65];
+	unsigned char Kxoropad[65];
+	md5_state_t ctx;
+	int pwlen;
+	char * pwinput;
+	char md5buf[16];
+
+	pwinput=(char *)passwd;
+	pwlen=strlen(passwd);
+	if (pwlen>64) {
+		md5_init(&ctx);
+		md5_append(&ctx, (unsigned char *)passwd, strlen(passwd));
+		md5_finish(&ctx, (unsigned char *)md5buf);
+		pwinput=(char *)md5buf;
+		pwlen=16;
+	}
+
+	memset(Kxoripad,0,sizeof(Kxoripad));
+	memset(Kxoropad,0,sizeof(Kxoropad));
+	memcpy(Kxoripad,pwinput,pwlen);
+	memcpy(Kxoropad,pwinput,pwlen);
+	for (i=0;i<64;i++) {
+		Kxoripad[i]^=0x36;
+		Kxoropad[i]^=0x5c;
+	}
+	md5_init(&ctx);
+	md5_append(&ctx, Kxoripad, 64);
+	md5_append(&ctx, challenge, challen);
+	md5_finish(&ctx, (unsigned char *)Kxoripad);
+
+	md5_init(&ctx);
+	md5_append(&ctx, Kxoropad, 64);
+	md5_append(&ctx, Kxoripad, 16);
+	md5_finish(&ctx, response);
+}
+
+static void
+s5_readchap(gpointer data, gint source, GaimInputCondition cond)
+{
+	unsigned char buf[260];
+	unsigned char cmdbuf[20];
+	struct PHB *phb = data;
+
+	int navas, currentav;
+
+	gaim_input_remove(phb->inpa);
+	gaim_debug(GAIM_DEBUG_INFO, "socks5 proxy", "Got CHAP response.\n");
+
+	if (read(source, cmdbuf, 2) < 2) {
+		close(source);
+
+		try_connect(phb);
+		return;
+	}
+
+	if (cmdbuf[0] != 0x01) {
+		close(source);
+
+		try_connect(phb);
+		return;
+	}
+
+	navas = cmdbuf[1];
+
+	for (currentav = 0; currentav < navas; currentav++) {
+		if (read(source, cmdbuf, 2) < 2) {
+			close(source);
+
+			try_connect(phb);
+			return;
+		}
+		if (read(source, buf, cmdbuf[1]) < cmdbuf[1]) {
+			close(source);
+
+			try_connect(phb);
+			return;
+		}
+		switch (cmdbuf[0]) {
+			case 0x00:
+				/* Did auth work? */
+				if (buf[0] == 0x00) {
+					/* Success */
+					s5_sendconnect(phb, source);
+					return;
+				} else {
+					/* Failure */
+					gaim_debug_warning("proxy", "socks5 CHAP authentication "
+									   "failed.  Disconnecting...");
+					close(source);
+
+					try_connect(phb);
+					return;
+				}
+				break;
+			case 0x03:
+				/* Server wants our credentials */
+				hmacmd5_chap(buf, cmdbuf[1],
+					gaim_proxy_info_get_password(phb->gpi),
+					buf + 4);
+				buf[0] = 0x01;
+				buf[1] = 0x01;
+				buf[2] = 0x04;
+				buf[3] = 0x10;
+				if (write(source, buf, 20) < 20) {
+					close(source);
+
+					try_connect(phb);
+					return;
+				}
+				break;
+			case 0x11:
+				/* Server wants to select an algorithm */
+				if (buf[0] != 0x85) {
+					/* Only currently support HMAC-MD5 */
+					gaim_debug_warning("proxy", "Server tried to select an "
+									   "algorithm that we did not advertise "
+									   "as supporting.  This is a violation "
+									   "of the socks5 CHAP specification.  "
+									   "Disconnecting...");
+					close(source);
+
+					try_connect(phb);
+					return;
+				}
+				break;
+		}
+	}
+	/* Fell through.  We ran out of CHAP events to process, but haven't
+	 * succeeded or failed authentication - there may be more to come.
+	 * If this is the case, come straight back here. */
+	phb->inpa = gaim_input_add(source, GAIM_INPUT_READ, s5_readchap, phb);
+}
+
 static void
 s5_canread(gpointer data, gint source, GaimInputCondition cond)
 {
@@ -1360,6 +1508,25 @@ s5_canread(gpointer data, gint source, GaimInputCondition cond)
 		}
 
 		phb->inpa = gaim_input_add(source, GAIM_INPUT_READ, s5_readauth, phb);
+	} else if (buf[1] == 0x03) {
+		unsigned int userlen;
+		userlen = strlen(gaim_proxy_info_get_username(phb->gpi));
+		buf[0] = 0x01;
+		buf[1] = 0x02;
+		buf[2] = 0x11;
+		buf[3] = 0x01;
+		buf[4] = 0x85;
+		buf[5] = 0x02;
+		buf[6] = userlen;
+		memcpy(buf + 7, gaim_proxy_info_get_username(phb->gpi), userlen);
+		if (write(source, buf, 7 + userlen) < 7 + userlen) {
+			close(source);
+
+			try_connect(phb);
+			return;
+		}
+
+		phb->inpa = gaim_input_add(source, GAIM_INPUT_READ, s5_readchap, phb);
 	}
 	else {
 		s5_sendconnect(phb, source);
@@ -1393,10 +1560,11 @@ s5_canwrite(gpointer data, gint source, GaimInputCondition cond)
 	buf[0] = 0x05;		/* SOCKS version 5 */
 
 	if (gaim_proxy_info_get_username(phb->gpi) != NULL) {
-		buf[1] = 0x02;	/* two methods */
+		buf[1] = 0x03;	/* three methods */
 		buf[2] = 0x00;	/* no authentication */
-		buf[3] = 0x02;	/* username/password authentication */
-		i = 4;
+		buf[3] = 0x03;	/* CHAP authentication */
+		buf[4] = 0x02;	/* username/password authentication */
+		i = 5;
 	}
 	else {
 		buf[1] = 0x01;
