@@ -575,23 +575,35 @@ void serv_rename_group(GaimConnection *gc, const char *old_name,
 		prpl_info = GAIM_PLUGIN_PROTOCOL_INFO(gc->prpl);
 
 	if (prpl_info && old_name && group && strcmp(old_name, group->name)) {
+		GList *l, *buddies = NULL;
+		/* Iterate through the list of buddies to move, and build a list
+		 * of the ones that belong to us.
+		 */
+		for(l = moved_buddies; l; l = l->next) {
+			GaimBuddy *buddy = (GaimBuddy *)l->data;
+
+			if(buddy && buddy->account == gc->account)
+				buddies = g_list_append(buddies, (GaimBlistNode *)buddy);
+		}
+
 		if (prpl_info->rename_group) {
 			/* prpl's might need to check if the group already
 			 * exists or not, and handle that differently */
-			prpl_info->rename_group(gc, old_name, group, moved_buddies);
+			prpl_info->rename_group(gc, old_name, group, buddies);
 		} else {
 			GList *cur, *groups = NULL;
 
 			/* Make a list of what the groups each buddy is in */
-			for (cur = moved_buddies; cur != NULL; cur = cur->next) {
+			for (cur = buddies; cur != NULL; cur = cur->next) {
 				GaimBlistNode *node = cur->data;
 				groups = g_list_append(groups, node->parent->parent);
 			}
 
-			serv_remove_buddies(gc, moved_buddies, groups);
+			serv_remove_buddies(gc, buddies, groups);
 			g_list_free(groups);
-			serv_add_buddies(gc, moved_buddies);
+			serv_add_buddies(gc, buddies);
 		}
+		g_list_free(buddies);
 	}
 }
 
@@ -1302,7 +1314,7 @@ void serv_got_update(GaimConnection *gc, const char *name, gboolean loggedin,
 	}
 
 	if (gc->login_time_official && gc->login_time && signon > 0)
-		signon += gc->login_time_official - gc->login_time;
+		signon -= gc->login_time_official - gc->login_time;
 	gaim_blist_update_buddy_signon(b, signon);
 	gaim_blist_update_buddy_idle(b, idle);
 	gaim_blist_update_buddy_evil(b, evil);
@@ -1460,6 +1472,8 @@ void serv_got_chat_invite(GaimConnection *gc, const char *name,
 	GaimAccount *account;
 	char buf2[BUF_LONG];
 	struct chat_invite_data *cid = g_new0(struct chat_invite_data, 1);
+	char *name_escaped = g_markup_escape_text(name, -1);
+	char *who_escaped = g_markup_escape_text(who, -1);
 
 	account = gaim_connection_get_account(gc);
 
@@ -1468,16 +1482,19 @@ void serv_got_chat_invite(GaimConnection *gc, const char *name,
 
 	if (message != NULL)
 	{
-		char *escaped = g_markup_escape_text(message, -1);
+		char *message_escaped = g_markup_escape_text(message, -1);
 		g_snprintf(buf2, sizeof(buf2),
 				   _("%s has invited %s to the chat room %s:\n<b>%s</b>"),
-				   who, gaim_account_get_username(account), name, escaped);
-		g_free(escaped);
+				   who_escaped, gaim_account_get_username(account), name_escaped, message_escaped);
+		g_free(message_escaped);
 	}
 	else
 		g_snprintf(buf2, sizeof(buf2),
 				   _("%s has invited %s to the chat room %s\n"),
-				   who, gaim_account_get_username(account), name);
+				   who_escaped, gaim_account_get_username(account), name_escaped);
+
+	g_free(name_escaped);
+	g_free(who_escaped);
 
 	cid->gc = gc;
 	cid->components = data;
